<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of Related, a plugin for DotClear2.
#
# Copyright(c) 2014-2015 Nicolas Roudaire <nikrou77@gmail.com> http://www.nikrou.net
#
# Copyright (c) 2006-2010 Pep and contributors.
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK ------------------------------------

class relatedPagesActionsPage extends dcPostsActionsPage
{
    public function __construct($core, $uri, $redirect_args=array()) {
		parent::__construct($core, $uri, $redirect_args);
		$this->redirect_fields = array();
		$this->caller_title = __('Related pages');
	}

	public function error(Exception $e) {
		$this->core->error->add($e->getMessage());
		$this->beginPage(dcPage::breadcrumb(
			array(
				html::escapeHTML($this->core->blog->name) => '',
				__('Pages') => $this->getRedirection(true),
				__('Pages actions') => ''
			))
		);
		$this->endPage();
	}

    public function beginPage($breadcrumb='', $head='') {
		echo
            '<html><head><title>'.__('Related pages').'</title>'.
			dcPage::jsLoad('js/_posts_actions.js').
			$head.
			'</script></head><body>'.
			$breadcrumb;
		echo '<p><a class="back" href="'.$this->getRedirection(true).'">'.__('Back to pages list').'</a></p>';
	}

	public function endPage() {
		echo '</body></html>';
	}

    public function loadDefaults() {
        dcDefaultPostActions::adminPostsActionsPage($this->core, $this);
		$this->actions['reorder'] = array($this, 'doReorderPages');
	}

    public function process() {
		if (!empty($this->from['reorder'])) {
			$this->from['action'] = 'reorder';
		}
		$this->from['post_type'] = 'related';

		return parent::process();
	}

    public static function doReorderPages($core, dcPostsActionsPage $ap, $post) {
        $meta = new dcMeta($core);

		foreach($post['order'] as $post_id => $value) {
			if (!$core->auth->check('publish,contentadmin',$core->blog->id)) {
				throw new Exception(__('You are not allowed to change this entry status'));
            }

			$strReq = "WHERE blog_id = '".$core->con->escape($core->blog->id)."' ";
            $strReq .= "AND post_id ".$core->con->in($post_id);

			# if user can only publish, we need to check the post's owner
			if (!$core->auth->check('contentadmin',$core->blog->id)) {
				$strReq .= "AND user_id = '".$core->con->escape($core->auth->userID())."' ";
            }

			$cur = $core->con->openCursor($core->prefix.'post');

            $meta->delPostMeta($post_id, 'related_position');
            $meta->setPostMeta($post_id, 'related_position', (integer) $value);

			$cur->post_position = (integer) $value;
			$cur->post_upddt = date('Y-m-d H:i:s');

			$cur->update($strReq);
		}
        if (count($post['order'])>0) {
            $core->blog->triggerBlog();
        }

		dcPage::addSuccessNotice(__('Selected pages have been successfully reordered.'));
		$ap->redirect(false);
	}
}